@@ -221,7 +221,7 @@ void AlbumWindow::uploadPhotos(QStringList files)
         datas += "\r\n";
         datas += QString("--" + boundary + "\r\n").toAscii();
 
-        QString url = QString("https://graph.facebook.com/%1/photos&access_token=" + accessToken).arg(albumId);
+        QString url = QString("https://graph.facebook.com/%1/photos?access_token=" + accessToken).arg(albumId);
         QNetworkRequest request(url);
         request.setAttribute(QNetworkRequest::User, info.baseName());
         request.setRawHeader("Content-Type", QString("multipart/form-data; boundary=" + boundary).toUtf8());
