@@ -11,6 +11,9 @@ CheckinDialog::CheckinDialog(QWidget *parent, QString token) :
     setAttribute(Qt::WA_DeleteOnClose);
     connect(QApplication::desktop(), SIGNAL(resized(int)), this, SLOT(orientationChanged()));
     this->orientationChanged();
+#ifdef Q_WS_MAEMO_5
+    setAttribute(Qt::WA_Maemo5ShowProgressIndicator, true);
+#endif
 }
 
 CheckinDialog::~CheckinDialog()
@@ -39,7 +42,6 @@ void CheckinDialog::onReplyReceived()
         qDebug() << "Failed to fetch places!";
         this->reply->deleteLater();
         this->reply = 0;
-
         return;
     }
 
