@@ -28,6 +28,8 @@ LoginWindow::LoginWindow(QWidget *parent) :
     setAttribute(Qt::WA_Maemo5StackedWindow);
     QWebViewSelectionSuppressor *suppressor = new QWebViewSelectionSuppressor(ui->webView);
     suppressor->enable();
+#else
+    this->parentWidget()->hide();
 #endif
 }
 
