@@ -102,6 +102,21 @@ void MainWindow::refreshAll()
         emit refresh();
 }
 
+void MainWindow::postUpdate()
+{
+    if (!m_statusUpdateDialog) {
+        m_statusUpdateDialog = new NewStatusUpdateDialog(this, qfacebook);
+    }
+#ifdef Q_WS_S60
+    m_statusUpdateDialog->showMaximized();
+#else
+    m_statusUpdateDialog->show();
+#endif
+
+    if (!m_statusUpdateDialog->isActiveWindow())
+        m_statusUpdateDialog->activateWindow();
+}
+
 void MainWindow::saveFavorites()
 {
     favorites.clear();
@@ -399,10 +414,16 @@ void MainWindow::createLoginWindow()
     loginWindow->show();
 #endif
     QTimer::singleShot(100, loginWindow, SLOT(raise()));
+#ifndef Q_WS_MAEMO_5
+    this->hide();
+#endif
 }
 
 void MainWindow::onLoggedIn(QString token)
 {
+#ifndef Q_WS_MAEMO_5
+    this->show();
+#endif
     this->accessToken = token;
     this->getNotifications();
     notificationsDialog = new NotificationsDialog(this, accessToken);
