@@ -25,7 +25,7 @@ NewsFeedPost::NewsFeedPost(QWidget *parent, QString token, QFacebook *qfacebook,
     connect(this, SIGNAL(customContextMenuRequested(QPoint)), this, SLOT(showContextMenu(QPoint)));
 
     this->orientationChanged();
-    this->isLikedByMe = false;
+    m_isLikedByMe = false;
     ui->deleteButton->hide();
     QPalette p = this->palette();
     p.setColor(QPalette::Foreground, p.highlight().color());
@@ -55,13 +55,13 @@ NewsFeedPost::~NewsFeedPost()
 
 void NewsFeedPost::onCommentButtonClicked()
 {
-    emit commentButtonClicked(this->id, this->comments, this->likes);
+    emit commentButtonClicked(this->id, m_numberOfComments, this->likes);
 }
 
 void NewsFeedPost::onLikeButtonClicked()
 {
     QByteArray data;
-    if (this->isLikedByMe)
+    if (m_isLikedByMe)
         data.append("&method=delete");
     this->reply = qfacebook->putObject(this->id, "likes", data);
     if (this->reply)
@@ -84,6 +84,11 @@ void NewsFeedPost::onToNameClicked()
     emit nameClicked(m_toUserId, ui->toLabel->text().remove("-> "));
 }
 
+QString NewsFeedPost::postId()
+{
+    return id;
+}
+
 void NewsFeedPost::onLikeReplyReceived()
 {
     if (this->reply->error() != QNetworkReply::NoError) {
@@ -94,12 +99,12 @@ void NewsFeedPost::onLikeReplyReceived()
         return;
     }
 
-    if (this->isLikedByMe) {
-        this->isLikedByMe = false;
-        this->setNumberOfLikesComments(QString::number(this->likes.toInt()-1).remove("\""), this->comments);
+    if (m_isLikedByMe) {
+        m_isLikedByMe = false;
+        this->setNumberOfLikesComments(QString::number(this->likes.toInt()-1).remove("\""), m_numberOfComments);
     } else {
-        this->isLikedByMe = true;
-        this->setNumberOfLikesComments(QString::number(this->likes.toInt()+1).remove("\""), this->comments);
+        m_isLikedByMe = true;
+        this->setNumberOfLikesComments(QString::number(this->likes.toInt()+1).remove("\""), m_numberOfComments);
     }
     reply->deleteLater();
 }
@@ -279,18 +284,12 @@ void NewsFeedPost::setTimeFromString(QString timeAsString)
 
 void NewsFeedPost::setDeletable(bool deletable)
 {
-    this->isDeletable = deletable;
+    m_isDeletable = deletable;
     ui->deleteButton->setVisible(deletable);
 }
 
 void NewsFeedPost::setAvatar(QPixmap pixmap)
 {
-    QPropertyAnimation *animation = new QPropertyAnimation(ui->avatarLabel, "pos", this);
-    animation->setStartValue(QPoint(ui->avatarLabel->x(), ui->avatarLabel->y()-(ui->avatarLabel->height()+70)));
-    animation->setEndValue(ui->avatarLabel->pos());
-    animation->setDuration(1000);
-    animation->setEasingCurve(QEasingCurve::InOutBack);
-    animation->start(QPropertyAnimation::DeleteWhenStopped);
     ui->avatarLabel->setPixmap(pixmap);
 }
 
@@ -316,20 +315,27 @@ void NewsFeedPost::hideBottomBar(bool hide)
 void NewsFeedPost::setNumberOfLikesComments(QString likes, QString comments)
 {
     QString likeText;
-    if (this->isLikedByMe)
+    if (m_isLikedByMe)
         likeText = tr("Unlike");
     else
         likeText = tr("Like");
     this->likes = likes;
-    this->comments = comments;
-    ui->commentButton->setText(tr("Comment") + QString(" (%1)").arg(comments));
-    ui->likeButton->setText(likeText + QString(" (%1)").arg(likes));
+    m_numberOfComments = comments;
+    QString commentsText = tr("Comment");
+    if (comments.toInt() > 0)
+        commentsText.append(QString(" (%1)").arg(comments));
+
+    if (likes.toInt() > 0)
+        likeText.append(QString(" (%1)").arg(likes));
+
+    ui->commentButton->setText(commentsText);
+    ui->likeButton->setText(likeText);
 }
 
 void NewsFeedPost::setLikedByMe(bool meLikesThis)
 {
-    this->isLikedByMe = meLikesThis;
-    this->setNumberOfLikesComments(this->likes, this->comments);
+    m_isLikedByMe = meLikesThis;
+    this->setNumberOfLikesComments(this->likes, m_numberOfComments);
 }
 
 void NewsFeedPost::setIconFromUrl(QString url)
@@ -523,8 +529,9 @@ void NewsFeedPost::mouseReleaseEvent(QMouseEvent *ev)
     }
 }
 
-void NewsFeedPost::showEvent(QShowEvent *)
+void NewsFeedPost::showEvent(QShowEvent *event)
 {
+    QWidget::showEvent(event);
 #if 0
     QPropertyAnimation *animation = new QPropertyAnimation(this, "pos", this);
     animation->setStartValue(QPoint(this->x()-this->width(), this->y()));
