@@ -55,6 +55,7 @@ public:
     void setToName(QString name, QString id);
     void setType(QString type);
     void setObjectId(QString objectId);
+    QString postId();
     QString type();
 
 protected:
@@ -82,16 +83,16 @@ private:
     QString id;
     QNetworkAccessManager *nam;
     QNetworkReply *pictureReply;
-    QString comments;
+    QString m_numberOfComments;
     QString likes;
     QString userId;
     QString m_toUserId;
     QString m_postType;
     QString m_objectId;
     QString m_linkUrl;
-    bool isLikedByMe;
-    bool isDeletable;
-    bool isComment;
+    bool m_isLikedByMe;
+    bool m_isDeletable;
+    bool m_isComment;
     bool m_pressed;
     bool m_whiteMode;
 
