@@ -41,22 +41,22 @@ private:
     QPointer<QFacebookReply> reply;
     QPointer<QFacebookReply> statusReply;
     QNetworkAccessManager *nam;
-    QList<NewsFeedPost*> posts;
+    QMap<QString,NewsFeedPost*> posts;
     QString myId;
     QString myName;
     QVariant m_postsVariant;
     QPointer<LoadingWidget> m_loadingWidget;
     QPointer<NewStatusUpdateDialog> m_statusUpdateDialog;
+    NewsFeedPost* getPostById(QString id);
+    bool m_isInitialRefresh;
 
 private slots:
     void onNewStatusUpdateButtonClicked();
-    void postUpdate(QString, QString, QString);
     void updateNewsFeed();
     void onReplyFinished();
     void orientationChanged();
     void onCommentButtonClicked(QString, QString, QString);
     void onNameClicked(QString, QString);
-    void onStatusUpdateReplyFinished();
     void onParserThreadFinished();
     void onNewsFeedItemParsed(QString fromName, QString fromId, bool isDeletable, QString message, QString icon, QString time,
                               QString link, QString linkName, QString linkDescription, QString linkPicture, QString toId, QString toName,
