@@ -35,7 +35,7 @@ void NotificationsDialog::orientationChanged()
 
 void NotificationsDialog::getNoficiationCount()
 {
-    QString url = QString("https://api.facebook.com/method/notifications.get&access_token=%1").arg(accessToken);
+    QString url = QString("https://api.facebook.com/method/notifications.get?access_token=%1").arg(accessToken);
     countReply = nam->get(QNetworkRequest(url));
     if (countReply)
         connect(countReply, SIGNAL(finished()), this, SLOT(onGotNotificationsCount()));
@@ -84,9 +84,7 @@ void NotificationsDialog::updateNotifications()
     setAttribute(Qt::WA_Maemo5ShowProgressIndicator, true);
 #endif
 
-    QString url;
-    url = QString("https://api.facebook.com/method/notifications.getList&include_read=true&access_token=%1").arg(accessToken);
-    reply = nam->get(QNetworkRequest(url));
+    reply = qfacebook->getConnections("me", "notifications&include_read=1");
     if (reply) {
         connect(reply, SIGNAL(finished()), this, SLOT(onNotificationsListReceived()));
         isFetching = true;
@@ -109,14 +107,14 @@ void NotificationsDialog::onNotificationsListReceived()
         return;
     }
 
-    QByteArray notificationsArray = reply->readAll();
-    if (notificationsArray == m_notifications) {
+    QVariant notificationsVariant = reply->data();
+    if (notificationsVariant == m_notifications) {
 #ifdef Q_WS_MAEMO_5
     setAttribute(Qt::WA_Maemo5ShowProgressIndicator, false);
 #endif
         return;
     } else {
-        m_notifications = notificationsArray;
+        m_notifications = notificationsVariant;
     }
 
     if (!notificationItems.isEmpty()) {
@@ -127,110 +125,81 @@ void NotificationsDialog::onNotificationsListReceived()
         }
     }
 
-    QList< QMap<QString,QString> > notifications;
-    QXmlStreamReader xml(notificationsArray);
-
-    while (!xml.atEnd() && !xml.hasError()) {
-        QXmlStreamReader::TokenType token = xml.readNext();
-        /* If token is just StartDocument, we'll go to next.*/
-        if (token == QXmlStreamReader::StartDocument) {
-                continue;
-        }
-        /* If token is StartElement, we'll see if we can read it.*/
-        if (token == QXmlStreamReader::StartElement) {
-            if (xml.name().toString().contains("notifications list"))
-                continue;
-            if (xml.name() == "notification")
-                notifications.append(this->parseNotification(xml));
-        }
-    }
-    /* Error handling. */
-    if (xml.hasError()) {
-        qDebug() << xml.errorString();
-    }
-    /* Removes any device() or data from the reader
-     * and resets its internal state to the initial state. */
-    xml.clear();
-    this->addNotificationsToUi(notifications);
-}
-
-QMap <QString, QString> NotificationsDialog::parseNotification(QXmlStreamReader &xml)
-{
-    QMap <QString, QString> notification;
-    while (!(xml.tokenType() == QXmlStreamReader::EndElement &&
-                xml.name() == "notification")) {
-        if(xml.tokenType() == QXmlStreamReader::StartElement) {
-                if (xml.name() == "notification_id")
-                    this->addElementDataToMap(xml, notification);
-                if (xml.name() == "sender_id")
-                    this->addElementDataToMap(xml, notification);
-                if (xml.name() == "title_text")
-                    this->addElementDataToMap(xml, notification);
-                if (xml.name() == "body_text")
-                    this->addElementDataToMap(xml, notification);
-                if (xml.name() == "created_time")
-                    this->addElementDataToMap(xml, notification);
-                if (xml.name() == "object_id")
-                    this->addElementDataToMap(xml, notification);
-                if (xml.name() == "object_type")
-                    this->addElementDataToMap(xml, notification);
-                if (xml.name() == "icon_url")
-                    this->addElementDataToMap(xml, notification);
-                if (xml.name() == "is_unread")
-                    this->addElementDataToMap(xml, notification);
-                if (xml.name() == "href")
-                    this->addElementDataToMap(xml, notification);
-        }
-        xml.readNext();
-    }
-    return notification;
-}
-
-void NotificationsDialog::addElementDataToMap(QXmlStreamReader& xml, QMap<QString, QString>& map) const
-{
-    if (xml.tokenType() != QXmlStreamReader::StartElement) {
-        return;
-    }
-    QString elementName = xml.name().toString();
-    xml.readNext();
-
-    if (xml.tokenType() != QXmlStreamReader::Characters) {
-        return;
-    }
-    map.insert(elementName, xml.text().toString());
-}
-
-void NotificationsDialog::addNotificationsToUi(QList< QMap<QString,QString> >& notifications)
-{
-    unreadCount = 0;
     m_unreadNotifications.clear();
     m_notifier->clearNotifications();
-    while (!notifications.isEmpty()) {
-        QMap<QString,QString> notification = notifications.takeFirst();
-        QString text = notification["title_text"];
+    unreadCount = 0;
+
+    QVariantList listData = notificationsVariant.toMap().value("data").toList();
+
+    foreach (QVariant jsonData, listData) {
+        QString text = jsonData.toMap().value("title").toString();
+
+        // notif_USER-ID-HERE_NOTIFICATION-ID
+        // Butcher this to get the last part
+
+        QString notificationIdTmp = jsonData.toMap().value("id").toString();
+
+        int indexOf = notificationIdTmp.lastIndexOf("_");
+        QString notificationId = notificationIdTmp.remove(0, indexOf);
+        // Just in case...
+        notificationId.remove("_");
+
+        // So apparently facebook removes this too, gotta butcher URLs to get it
+        // QString objectId = jsonData.toMap().value("object_id").toString();
+
+        // And... it's back, with the Graph API ~November 30, 2012
+        QString objectId = jsonData.toMap().value("object").toMap().value("id").toString();
+        QString objectType = jsonData.toMap().value("object").toMap().value("type").toString();
+        QString senderId = jsonData.toMap().value("object").toMap().value("from").toMap().value("id").toString();
+        if (senderId.isEmpty()) {
+            senderId = jsonData.toMap().value("from").toMap().value("id").toString();
+        }
+        QString avatarUrl = "https://graph.facebook.com/" + senderId + "/picture" + "&accessToken=" + accessToken;
+        QString link = jsonData.toMap().value("link").toString();
+        QString pictureUrl = jsonData.toMap().value("object").toMap().value("picture").toString();
+        QString applicationId = jsonData.toMap().value("application").toMap().value("id").toString();
+        QString statusType = jsonData.toMap().value("object").toMap().value("status_type").toString();
+        bool isUnread = jsonData.toMap().value("unread").toBool();
+
+        if (objectType.isEmpty()) {
+            if (link.contains("photo.php")) {
+                objectType = "photo";
+            } else if (link.contains("pokes")) {
+                objectType = "poke";
+            } else if (!jsonData.toMap().value("object").toMap().value("place").toMap().isEmpty()) {
+                objectType = "status";
+            }
+        }
+
+        if (objectType == "group" || applicationId == FACEBOOK_APPLICATION_GROUPS_ID) {
+            QString href = link;
+            href.remove("http://www.facebook.com/groups/");
+            if (href.contains("comment_id")) {
+                int pos = href.lastIndexOf("/");
+                href.remove(pos, href.size()-pos);
+            }
+            href.replace("/", "_");
+            if (href.endsWith("_"))
+                href.chop(1);
+
+            objectId = href;
+            objectType = "status";
+        }
+
+        if (statusType == "shared_story") {
+            objectType = "status";
+        }
+
         if (!text.isEmpty()) {
             NotificationItem *item = new NotificationItem(this, accessToken, nam);
             connect(item, SIGNAL(markedAsRead(NotificationItem*)), this, SLOT(onMarkedAsRead(NotificationItem*)));
             connect(item, SIGNAL(clicked(NotificationItem*)), this, SLOT(onNotificationClicked(NotificationItem*)));
-            QString objectType = notification["object_type"];
-            if (objectType == "photo") {
-                // Not sure which ID facebook returns in Object ID, but it doesn't seem valid
-                QString href = notification["href"];
-                href = href.remove("http://www.facebook.com/photo.php?fbid=");
-                int position = href.indexOf("&");
-                href.remove(position, href.length()-position);
-                item->setObjectId(href);
-            } else {
-                item->setObjectId(notification["object_id"]);
-            }
-
+            item->setObjectId(objectId);
             item->setObjectType(objectType);
-            item->setUserId(notification["sender_id"]);
-            item->setText(notification["title_text"]);
-            item->setNotificationId(notification["notification_id"]);
-            bool isUnread = false;
-            if (notification["is_unread"].toInt() == 1) {
-                isUnread = true;
+            item->setUserId(senderId);
+            item->setText(text);
+            item->setNotificationId(notificationId);
+            if (isUnread) {
                 m_unreadNotifications.append(item);
                 m_notifier->createNotification("Facebook", item->text(), "general_facebook");
                 m_notifier->vibrate();
@@ -253,7 +222,8 @@ void NotificationsDialog::onNotificationClicked(NotificationItem *item)
 {
     item->markAsRead();
     QString type = item->objectType();
-    if (type == "stream") {
+    qDebug() << type;
+    if (type == "status") {
         SinglePostWindow *post = new SinglePostWindow(this->parentWidget(), accessToken);
         post->loadPost(item->objectId());
 #ifdef Q_WS_S60
