@@ -28,7 +28,7 @@ PhotoWindow::~PhotoWindow()
 void PhotoWindow::showPhoto(QString photoId)
 {
     this->photoId = photoId;
-    QString urlString = QString("https://graph.facebook.com/%1/picture&type=large&access_token=%2").arg(photoId, accessToken);
+    QString urlString = QString("https://graph.facebook.com/%1/picture?type=large&access_token=%2").arg(photoId, accessToken);
     m_photoUrl = urlString;
     this->reply = nam->get(QNetworkRequest(urlString));
     if (this->reply)
@@ -39,7 +39,7 @@ void PhotoWindow::showPhotoFromId(QString id)
 {
     this->photoId = id;
     this->getCommentsForPhoto(id);
-    QString urlString = QString("https://graph.facebook.com/%1/picture&type=normal&access_token=%2").arg(photoId, accessToken);
+    QString urlString = QString("https://graph.facebook.com/%1/picture?type=normal&access_token=%2").arg(photoId, accessToken);
     qDebug() << urlString;
     m_photoUrl = urlString;
     this->reply = nam->get(QNetworkRequest(urlString));
